# Analyzer Plugin Spec

This page is currently maintained in Chinese first.

- Chinese page: [Analyzer 插件接口草案](../../zh/advanced/analyzer_plugin_spec.md)
- Related code: [analyzer_plugin.py](https://github.com/akfamily/akquant/blob/main/python/akquant/analyzer_plugin.py)
- Related docs:
  - [Runtime Config Guide](runtime_config.md)
  - [API Reference](../reference/api.md)
